"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _isRequiredForA11y = _interopRequireDefault(require("prop-types-extra/lib/isRequiredForA11y"));
var _bootstrapUtils = require("./utils/bootstrapUtils");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const propTypes = {
  /**
   * An html id attribute, necessary for accessibility
   * @type {string|number}
   * @required
   */
  id: (0, _isRequiredForA11y.default)(_propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number])),
  /**
   * Sets the direction the Tooltip is positioned towards.
   */
  placement: _propTypes.default.oneOf(['top', 'right', 'bottom', 'left']),
  /**
   * The "top" position value for the Tooltip.
   */
  positionTop: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
  /**
   * The "left" position value for the Tooltip.
   */
  positionLeft: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
  /**
   * The "top" position value for the Tooltip arrow.
   */
  arrowOffsetTop: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
  /**
   * The "left" position value for the Tooltip arrow.
   */
  arrowOffsetLeft: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
};
const defaultProps = {
  placement: 'right'
};
class Tooltip extends _react.default.Component {
  render() {
    const {
      placement,
      positionTop,
      positionLeft,
      arrowOffsetTop,
      arrowOffsetLeft,
      className,
      style,
      children,
      ...props
    } = this.props;
    const [bsProps, elementProps] = (0, _bootstrapUtils.splitBsProps)(props);
    const classes = {
      ...(0, _bootstrapUtils.getClassSet)(bsProps),
      [placement]: true
    };
    const outerStyle = {
      top: positionTop,
      left: positionLeft,
      ...style
    };
    const arrowStyle = {
      top: arrowOffsetTop,
      left: arrowOffsetLeft
    };
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
      ...elementProps,
      role: "tooltip",
      className: (0, _classnames.default)(className, classes),
      style: outerStyle,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        className: (0, _bootstrapUtils.prefix)(bsProps, 'arrow'),
        style: arrowStyle
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        className: (0, _bootstrapUtils.prefix)(bsProps, 'inner'),
        children: children
      })]
    });
  }
}
Tooltip.propTypes = propTypes;
Tooltip.defaultProps = defaultProps;
var _default = exports.default = (0, _bootstrapUtils.bsClass)('tooltip', Tooltip);
//# sourceMappingURL=Tooltip.js.map